@@ -35,6 +35,11 @@ def test_ubai_search_cli(set_environment_variable):
     call_cli()
 
 
+@pytest.mark.parametrize(
+    "set_environment_variable",
+    [("DISABLE_SSL_VERIFICATION", "true"), ("DISABLE_SSL_VERIFICATION", "false")],
+    indirect=True,
+)
 @pytest.mark.parametrize(
     "args",
     [
@@ -44,7 +49,7 @@ def test_ubai_search_cli(set_environment_variable):
     ],
 )
 @instrumented
-def test_ubai_search_cli_script(args):
+def test_ubai_search_cli_script(args, set_environment_variable):
     metadata = [
         ("app_name", "ubai_unit_test"),
         ("branch", "master"),
