@@ -5,10 +5,11 @@ from ..models import SqaAppBuildResult
 from ..models import SqaTestResult
 from ..models import SqaTestSession
 from ..models import QueueMessage
-from . import Loggable, create_span_decorator
+from . import Loggable
 from socket import gethostname
 from datetime import datetime
 from abc import ABC, abstractmethod
+from otel_extensions import instrumented
 
 __all__ = [
     "SqaTestResultProducer",
@@ -17,28 +18,26 @@ __all__ = [
     "SqaTestResultProducerFactory",
 ]
 
-span_decorator = create_span_decorator()
-
 
 class BaseSqaTestResultProducer(ABC):
     @abstractmethod
     def publish_test_result(self, test_result: SqaTestResult):
-        pass
+        """publish an SqaTestResult object"""
 
     @abstractmethod
     def publish_test_session_start(self, test_session: SqaTestSession):
-        pass
+        """publish an SqaTestSession object when starting a test session"""
 
     @abstractmethod
     def publish_test_session_stop(self, test_session: SqaTestSession):
-        pass
+        """publish an SqaTestSession object when stopping a test session"""
 
     @abstractmethod
     def publish_app_build_result(
         self,
         app_build_result: SqaAppBuildResult,
     ):
-        pass
+        """publish an SqaAppBuildResult object"""
 
 
 class SqaTestResultProducer(BaseSqaTestResultProducer):
@@ -59,7 +58,7 @@ class SqaTestResultProducer(BaseSqaTestResultProducer):
             persistent=True,
         )
 
-    @span_decorator
+    @instrumented
     def publish_test_result(self, test_result: SqaTestResult):
         queue_message = QueueMessage(
             payload=test_result,
@@ -70,7 +69,7 @@ class SqaTestResultProducer(BaseSqaTestResultProducer):
         )
         self._publish_message(queue_message)
 
-    @span_decorator
+    @instrumented
     def publish_test_session(self, subtype: str, test_session: SqaTestSession):
         queue_message = QueueMessage(
             payload=test_session,
@@ -81,15 +80,15 @@ class SqaTestResultProducer(BaseSqaTestResultProducer):
         )
         self._publish_message(queue_message)
 
-    @span_decorator
+    @instrumented
     def publish_test_session_start(self, test_session: SqaTestSession):
         self.publish_test_session("SESSION_START", test_session)
 
-    @span_decorator
+    @instrumented
     def publish_test_session_stop(self, test_session: SqaTestSession):
         self.publish_test_session("SESSION_STOP", test_session)
 
-    @span_decorator
+    @instrumented
     def publish_app_build_result(
         self,
         app_build_result: SqaAppBuildResult,
